@@ -3,6 +3,7 @@ import pymongo
 import pymongo.collection
 import pymongo.database
 import pymongo.dbref
+import pymongo.objectid
 from minimongo import config
 
 
@@ -36,7 +37,11 @@ class Collection(pymongo.collection.Collection):
 
 class MongoCollection(object):
     """Container class for connection to db & mongo collection settings."""
-    def __init__(self, host=None, port=None, database=None, collection=None):
+    def __init__(self, host=None, port=None, database=None, collection=None,
+                 placeholder=False):
+        if placeholder:
+            if host or port or database or collection:
+                raise Exception("Placeholder configs can't also specify other params")
         if not host:
             host = config.MONGODB_HOST
         if not port:
@@ -45,6 +50,7 @@ class MongoCollection(object):
         self.port = port
         self.database = database
         self.collection = collection
+        self.placeholder = placeholder
 
 
 class Meta(type):
@@ -72,12 +78,13 @@ class Meta(type):
         # This constructor runs on the Model class as well as the derived
         # classes.  When we're a Model, we don't have a proper
         # configuration, so we just skip the connection stuff below.
-        if name == 'Model':
+        if collection_info.placeholder:
             new_cls.database = None
             new_cls.collection = None
             return new_cls
 
-        if not (host and port and dbname and collname):
+        if (not collection_info.placeholder
+            and not (host and port and dbname and collname)):
             raise Exception(
                 'minimongo Model %s %s improperly configured: %s %s %s %s' % (
                     mcs, name, host, port, dbname, collname))
@@ -113,16 +120,30 @@ class Meta(type):
 class Model(dict):
     """Base class for all Minimongo objects.  Derive from this class."""
     __metaclass__ = Meta
-    mongo = MongoCollection()
+    mongo = MongoCollection(placeholder=True)
 
     # These lines make this object behave both like a dict (x['y']) and like
-    # an object (x.y)
+    # an object (x.y).  We have to translate from KeyError to AttributeError
+    # since model.undefined raises a KeyError and model['undefined'] raises
+    # a KeyError.  we don't ever want __getattr__ to raise a KeyError, so we
+    # "translate" them below:
     def __getattr__(*args, **kwargs):
-        return dict.__getitem__(*args, **kwargs)
+        try:
+            return dict.__getitem__(*args, **kwargs)
+        except KeyError, excn:
+            raise AttributeError(excn)
+
     def __setattr__(*args, **kwargs):
-        return dict.__setitem__(*args, **kwargs)
+        try:
+            return dict.__setitem__(*args, **kwargs)
+        except KeyError, excn:
+            raise AttributeError(excn)
+
     def __delattr__(self, key):
-        del self[key]
+        try:
+            del self[key]
+        except KeyError, excn:
+            raise AttributeError(excn)
 
     def __init__(self, initial_value=None):
         if initial_value:
@@ -131,7 +152,7 @@ class Model(dict):
     def dbref(self):
         """Return an instance of a DBRef for the current object."""
         if not hasattr(self, '_id'):
-            self._id = pymongo.ObjectId()
+            self._id = pymongo.objectid.ObjectId()
         assert self._id != None, "ObjectId must be valid to create DBRef"
         return pymongo.dbref.DBRef(collection=self.collection.name,
                                    id=self._id,
